import y from "y;";
const obj = y;
